文件列表 - MediaWiki

跳转到内容

# 文件列表

帮助

本特殊页面展示所有上传的文件。

文件列表
每页项数：
7
20
50
100
250
500
用户名：
包括文件的旧版本
首页上一页下一页末页

日期 | 名称 | 缩⁠略⁠图 | 大小 | 用户 | 描述
--- | --- | --- | --- | --- | ---
2006年12月2日 (六) 10:33 | Example.jpg （文件） |  | 60 KB | Bdk（留言 | 贡献） | smaller version
2007年2月24日 (六) 21:00 | BadImageList.png （文件） |  | 51 KB | Robchurch（留言 | 贡献） | Crop whitespace from the right of the screenshot
2007年4月30日 (一) 10:36 | M-fi-recentchanges.png （文件） |  | 130 KB | Cimon Avaro（留言 | 贡献） | screencapture for the PD-helpfiles
2007年5月14日 (一) 14:54 | NiceCategoryList2 extension example.jpg （文件） |  | 28 KB | JohanTheGhost（留言 | 贡献） | Example image (partial screenshot) demonstrating the NiceCategoryList2 extension. Made by me, JohanTheGhost, 14 May, 2007.
2007年5月15日 (二) 15:56 | NiceCategoryList2 extension default.jpg （文件） |  | 23 KB | JohanTheGhost（留言 | 贡献） | == Summary == Example image (partial screenshot) demonstrating the NiceCategoryList2 extension in its default mode. Made by me, JohanTheGhost, 15 May, 2007. == Licensing == {{GFDL}}
2007年5月15日 (二) 15:57 | NiceCategoryList2 extension full.jpg （文件） |  | 20 KB | JohanTheGhost（留言 | 贡献） | == Summary == Example image (partial screenshot) demonstrating the NiceCategoryList2 extension used to generate a full listing. Made by me, JohanTheGhost, 15 May, 2007. == Licensing == {{GFDL}}
2007年6月24日 (日) 03:06 | TinyMCE MW.PNG （文件） |  | 124 KB | JoeSox（留言 | 贡献） | TinyMCE_MW extension Screenshots

首页上一页下一页末页
检索自“https://www.mediawiki.org/wiki/Special:ListFiles”
文件列表
添加话题

语言已自English更改